@@ -1,13 +1,13 @@
-from . import ctx
+from .context import EventContext
 
 
 class ContextClient:
     """Class to be subclassed by discord.py Client to register EventContext hooks."""
     def __init__(self, *args, **kwargs):
         # noinspection PyTypeChecker
-        ctx.set_client(self)
+        EventContext.ctx.set_client(self)
         super().__init__(*args, **kwargs)
 
     def dispatch(self, event_name, *args, **kwargs):
-        ctx.event_hook(event_name, *args, **kwargs)
+        EventContext.ctx.event_hook(event_name, *args, **kwargs)
         super().dispatch(event_name, *args, **kwargs)
